@@ -36,7 +36,7 @@ class Table(object):
 
     @classmethod
     def from_list(cls, l, name=None):
-        return cls(df=l, name=name)
+        return Table(df=l, name=name)
 
     @property
     def Z(self):
@@ -222,4 +222,4 @@ class Table(object):
 
 if __name__ == '__main__':
     print Table('AME2003').head().join(Table('AME2012').head(), Table('DUZU').odd_odd.head())
-    print Table()
+    print Table.from_list([1,1])
